@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2019 Derick Rethans                               |
+   | Copyright (c) 1997-2021 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to the 2-Clause BSD license which is     |
    | available through the LICENSE file, or online at                     |
@@ -9,7 +9,6 @@
    | Authors:  Derick Rethans <derick@derickrethans.nl>                   |
    +----------------------------------------------------------------------+
  */
-/* $Id: vld.c,v 1.40 2009-03-30 18:36:55 derick Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -54,10 +53,10 @@ zend_module_entry vld_module_entry = {
 	vld_functions,
 	PHP_MINIT(vld),
 	PHP_MSHUTDOWN(vld),
-	PHP_RINIT(vld),	
+	PHP_RINIT(vld),
 	PHP_RSHUTDOWN(vld),
 	PHP_MINFO(vld),
-	"0.16.0",
+	"0.17.2",
 	STANDARD_MODULE_PROPERTIES
 };
 
@@ -80,7 +79,7 @@ PHP_INI_BEGIN()
 	STD_PHP_INI_ENTRY("vld.save_paths",   "0", PHP_INI_SYSTEM, OnUpdateBool, save_paths,   zend_vld_globals, vld_globals)
 	STD_PHP_INI_ENTRY("vld.dump_paths",   "1", PHP_INI_SYSTEM, OnUpdateBool, dump_paths,   zend_vld_globals, vld_globals)
 PHP_INI_END()
- 
+
 static void vld_init_globals(zend_vld_globals *vg)
 {
 	vg->active       = 0;
@@ -203,7 +202,7 @@ int vld_printf(FILE *stream, const char* fmt, ...)
 	size_t j = 0;
 	char *ptr;
 	const char EOL='\n';
-	
+
 	va_start(args, fmt);
 	len = vspprintf(&message, 0, fmt, args);
 	va_end(args);
@@ -223,7 +222,7 @@ int vld_printf(FILE *stream, const char* fmt, ...)
 	}
 
 	efree(message);
-	
+
 	return len;
 }
 
@@ -258,7 +257,7 @@ static int vld_dump_cle (zend_class_entry *class_entry)
 	zend_bool have_fe = 0;
 	ce = class_entry;
 
-	if (ce->type != ZEND_INTERNAL_CLASS) {	
+	if (ce->type != ZEND_INTERNAL_CLASS) {
 		if (VLD_G(path_dump_file)) {
 			fprintf(VLD_G(path_dump_file), "subgraph cluster_class_%s { label=\"class %s\";\n", ZSTRING_VALUE(ce->name), ZSTRING_VALUE(ce->name));
 		}
@@ -287,10 +286,15 @@ static int vld_dump_cle (zend_class_entry *class_entry)
 static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type)
 {
 	zend_op_array *op_array;
+#if PHP_VERSION_ID < 80100
+	char *filename = file_handle->filename;
+#else
+	char *filename = ZSTR_VAL(file_handle->filename);
+#endif
 
 	if (!VLD_G(execute) &&
-		((VLD_G(skip_prepend) && PG(auto_prepend_file) && PG(auto_prepend_file)[0] && PG(auto_prepend_file) == file_handle->filename) ||
-	     (VLD_G(skip_append)  && PG(auto_append_file)  && PG(auto_append_file)[0]  && PG(auto_append_file)  == file_handle->filename)))
+		((VLD_G(skip_prepend) && PG(auto_prepend_file) && PG(auto_prepend_file)[0] && PG(auto_prepend_file) == filename) ||
+	     (VLD_G(skip_append)  && PG(auto_append_file)  && PG(auto_append_file)[0]  && PG(auto_append_file)  == filename)))
 	{
 		zend_op_array *ret;
 #if PHP_VERSION_ID < 80000
